==> nextcloud-22.2.10.tgz: nextcloud/apps/dav/l10n/da.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Personal" : "Personligt",
    "{actor} created calendar {calendar}" : "{actor} oprettede kalenderen {calendar}",
    "You created calendar {calendar}" : "Du oprettede kalenderen {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} sletede kalenderen {calendar}",
    "You deleted calendar {calendar}" : "Du slettede kalenderen {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} opdaterede kalenderen {calendar}",
    "You updated calendar {calendar}" : "Du opdaterede kalenderen {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} gendannede kalender {calendar}",
    "You restored calendar {calendar}" : "Du gendannede kalender {calendar}",
    "You shared calendar {calendar} as public link" : "Du har delt kalenderen {calendar} som offentligt link",
    "You removed public link for calendar {calendar}" : "Du har fjernet det offentlige link til kalenderen {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delte kalenderen {calendar} med dig",
    "You shared calendar {calendar} with {user}" : "Du delte kalenderen {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delte kalenderen {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} fjernede delingen af  {calendar} fra dig",
    "You unshared calendar {calendar} from {user}" : "Du fjernede delingen af {calendar} fra {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} fjernede delingen af {calendar} fra {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} fjernede delingen af {calendar} fra sig selv",
    "You shared calendar {calendar} with group {group}" : "Du delte kalenderen {calendar} med gruppen {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delte kalenderen {calendar} med gruppen {group}",
    "You unshared calendar {calendar} from group {group}" : "Du fjernede delingen af  {calendar} fra gruppen {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} fjernede deling af kalenderen {calendar} fra gruppen {group}",
    "Untitled event" : "Unavngiven begivenhed",
    "{actor} created event {event} in calendar {calendar}" : "{actor} oprettede begivenheden {event} i kalenderen {calendar}",
    "You created event {event} in calendar {calendar}" : "Du oprettede begivenheden {event} i kalenderen {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} slettede begivenheden {event} fra kalenderen {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du slettede begivenheden {event} fra kalenderen {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} opdaterede begivenheden {event} i kalenderen {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du opdaterede begivenheden {event} i kalenderen {calendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} gendannede begivenhed {event} i kalender {calendar}",
    "You restored event {event} of calendar {calendar}" : "Du gendannede begivenhed {begivenhed} i kalender {kalender}",
    "Busy" : "Optaget",
    "Calendar, contacts and tasks" : "Kalender, kontakter og opgaver",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> er blevet ændret",
    "A calendar <strong>event</strong> was modified" : "En kalender <strong>begivenhed</strong> er blevet ændret",
    "Contact birthdays" : "Kontakt fødselsdag",
    "Death of %s" : "Død af%s",
    "Calendar:" : "Kalender:",
    "Date:" : "Dato:",
    "Where:" : "Hvor:",
    "Description:" : "Beskrivelse:",
    "_%n year_::_%n years_" : ["%n år","%n år"],
    "_%n month_::_%n months_" : ["%n måned","%n måneder"],
    "_%n day_::_%n days_" : ["%n dag","%n dage"],
    "_%n hour_::_%n hours_" : ["%n time","%n timer"],
    "_%n minute_::_%n minutes_" : ["%n minut","%n minutter"],
    "%s (in %s)" : "%s (i %s)",
    "%s (%s ago)" : "%s (%s siden)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Dato: %s",
    "Description: %s" : "Beskrivelse: %s",
    "Where: %s" : "Hvor: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Invitation canceled" : "Invitation annulleret",
    "Invitation updated" : "Invitation opdateret ",
    "Invitation" : "Invitation",
    "Title:" : "Titel:",
    "Time:" : "Tid:",
    "Location:" : "Sted:",
    "Link:" : "Link:",
    "Organizer:" : "Arrangør:",
    "Attendees:" : "Deltagere:",
    "Accept" : "Accepter",
    "Decline" : "Afvis",
    "More options …" : "Flere indstillinger…",
    "Contacts" : "Kontakter",
    "System is in maintenance mode." : "Systemet er i vedligeholdelsestilstand.",
    "Upgrade needed" : "Opgradering er nødvendig",
    "Tasks" : "Opgaver",
    "Contacts and groups" : "Kontakter og grupper",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV endpoint",
    "to" : "til",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sunday" : "Søndag",
    "Save" : "Gem",
    "Calendar server" : "Kalenderserver",
    "Send invitations to attendees" : "Send invitation til deltagere",
    "Automatically generate a birthday calendar" : "Generer en fødselsdagskalender automatisk",
    "Birthday calendars will be generated by a background job." : "Fødselsdagskalendere vil blive oprettet af et job, der kører i baggrunden.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Derfor vil de ikke blive synlige med det samme efter aktivering, men vil vise sig efter noget tid.",
    "Are you accepting the invitation?" : "Accepter du invitationen?",
    "Tentative" : "Foreløbig",
    "Comment" : "Kommentér",
    "Todos" : "Opgaver",
    "{actor} created todo {todo} in list {calendar}" : "{actor} oprettede en opgave {todo} i listen {calendar}",
    "You created todo {todo} in list {calendar}" : "Du oprettede opgaven {todo} i listen {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} slettede opgaven {todo} fra listen {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Du slettede opgaven {todo} fra listen {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} opdaterede opgaven {todo} i listen {calendar}",
    "You updated todo {todo} in list {calendar}" : "Du opdaterede opgaven {todo} i listen {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} løste opgaven {todo} i listen {calendar}",
    "You solved todo {todo} in list {calendar}" : "Du løste opgaven {todo} i listen {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} genåbnede opgaven {todo} i listen {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Du genåbnede opgaven {todo} i listen {calendar}",
    "A calendar <strong>todo</strong> was modified" : "En kalender  <strong>opgave</strong> blev ændret"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.12p0.tgz: nextcloud/apps/dav/l10n/da.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Personal" : "Personligt",
    "{actor} created calendar {calendar}" : "{actor} oprettede kalenderen {calendar}",
    "You created calendar {calendar}" : "Du oprettede kalenderen {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} sletede kalenderen {calendar}",
    "You deleted calendar {calendar}" : "Du slettede kalenderen {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} opdaterede kalenderen {calendar}",
    "You updated calendar {calendar}" : "Du opdaterede kalenderen {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} gendannede kalender {calendar}",
    "You restored calendar {calendar}" : "Du gendannede kalender {calendar}",
    "You shared calendar {calendar} as public link" : "Du har delt kalenderen {calendar} som offentligt link",
    "You removed public link for calendar {calendar}" : "Du har fjernet det offentlige link til kalenderen {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delte kalenderen {calendar} med dig",
    "You shared calendar {calendar} with {user}" : "Du delte kalenderen {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delte kalenderen {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} fjernede delingen af  {calendar} fra dig",
    "You unshared calendar {calendar} from {user}" : "Du fjernede delingen af {calendar} fra {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} fjernede delingen af {calendar} fra {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} fjernede delingen af {calendar} fra sig selv",
    "You shared calendar {calendar} with group {group}" : "Du delte kalenderen {calendar} med gruppen {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delte kalenderen {calendar} med gruppen {group}",
    "You unshared calendar {calendar} from group {group}" : "Du fjernede delingen af  {calendar} fra gruppen {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} fjernede deling af kalenderen {calendar} fra gruppen {group}",
    "Untitled event" : "Unavngiven begivenhed",
    "{actor} created event {event} in calendar {calendar}" : "{actor} oprettede begivenheden {event} i kalenderen {calendar}",
    "You created event {event} in calendar {calendar}" : "Du oprettede begivenheden {event} i kalenderen {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} slettede begivenheden {event} fra kalenderen {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du slettede begivenheden {event} fra kalenderen {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} opdaterede begivenheden {event} i kalenderen {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du opdaterede begivenheden {event} i kalenderen {calendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} gendannede begivenhed {event} i kalender {calendar}",
    "You restored event {event} of calendar {calendar}" : "Du gendannede begivenhed {begivenhed} i kalender {kalender}",
    "Busy" : "Optaget",
    "Calendar, contacts and tasks" : "Kalender, kontakter og opgaver",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> er blevet ændret",
    "A calendar <strong>event</strong> was modified" : "En kalender <strong>begivenhed</strong> er blevet ændret",
    "Contact birthdays" : "Kontakt fødselsdag",
    "Death of %s" : "Død af%s",
    "Calendar:" : "Kalender:",
    "Date:" : "Dato:",
    "Where:" : "Hvor:",
    "Description:" : "Beskrivelse:",
    "_%n year_::_%n years_" : ["%n år","%n år"],
    "_%n month_::_%n months_" : ["%n måned","%n måneder"],
    "_%n day_::_%n days_" : ["%n dag","%n dage"],
    "_%n hour_::_%n hours_" : ["%n time","%n timer"],
    "_%n minute_::_%n minutes_" : ["%n minut","%n minutter"],
    "%s (in %s)" : "%s (i %s)",
    "%s (%s ago)" : "%s (%s siden)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Dato: %s",
    "Description: %s" : "Beskrivelse: %s",
    "Where: %s" : "Hvor: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Invitation canceled" : "Invitation annulleret",
    "Invitation updated" : "Invitation opdateret ",
    "Invitation" : "Invitation",
    "Title:" : "Titel:",
    "Time:" : "Tid:",
    "Location:" : "Sted:",
    "Link:" : "Link:",
    "Organizer:" : "Arrangør:",
    "Attendees:" : "Deltagere:",
    "Accept" : "Accepter",
    "Decline" : "Afvis",
    "More options …" : "Flere indstillinger…",
    "Contacts" : "Kontakter",
    "System is in maintenance mode." : "Systemet er i vedligeholdelsestilstand.",
    "Upgrade needed" : "Opgradering er nødvendig",
    "Tasks" : "Opgaver",
    "Untitled task" : "Unavngivet opgave",
    "Contacts and groups" : "Kontakter og grupper",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV endpoint",
    "Availability" : "tilgængelighed",
    "to" : "til",
    "Delete slot" : "Slet slot",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sunday" : "Søndag",
    "Save" : "Gem",
    "Calendar server" : "Kalenderserver",
    "Send invitations to attendees" : "Send invitation til deltagere",
    "Automatically generate a birthday calendar" : "Generer en fødselsdagskalender automatisk",
    "Birthday calendars will be generated by a background job." : "Fødselsdagskalendere vil blive oprettet af et job, der kører i baggrunden.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Derfor vil de ikke blive synlige med det samme efter aktivering, men vil vise sig efter noget tid.",
    "Are you accepting the invitation?" : "Accepter du invitationen?",
    "Tentative" : "Foreløbig",
    "Comment" : "Kommentér",
    "Todos" : "Opgaver",
    "{actor} created todo {todo} in list {calendar}" : "{actor} oprettede en opgave {todo} i listen {calendar}",
    "You created todo {todo} in list {calendar}" : "Du oprettede opgaven {todo} i listen {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} slettede opgaven {todo} fra listen {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Du slettede opgaven {todo} fra listen {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} opdaterede opgaven {todo} i listen {calendar}",
    "You updated todo {todo} in list {calendar}" : "Du opdaterede opgaven {todo} i listen {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} løste opgaven {todo} i listen {calendar}",
    "You solved todo {todo} in list {calendar}" : "Du løste opgaven {todo} i listen {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} genåbnede opgaven {todo} i listen {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Du genåbnede opgaven {todo} i listen {calendar}",
    "A calendar <strong>todo</strong> was modified" : "En kalender  <strong>opgave</strong> blev ændret"
},
"nplurals=2; plural=(n != 1);");
